@@ -1,13 +1,5 @@
 /*
- *                
- * Filename:      cobex_bfb.h
- * Version:       
- * Description:   
- * Status:        Experimental.
- * Author:        Christian W. Zuckschwerdt <zany@triq.net>
- * Created at:    Don, 17 Jan 2002 18:27:25 +0100
- * Modified at:   Don, 17 Jan 2002 23:46:52 +0100
- * Modified by:   Christian W. Zuckschwerdt <zany@triq.net>
+ * cobex_bfb.h
  *
  *   Copyright (c) 2002 Christian W. Zuckschwerdt <zany@triq.net>
  * 
@@ -27,20 +19,32 @@
  *     
  */
 
+#ifndef COBEXBFB_H
+#define COBEXBFB_H
+
+#include <stdint.h>
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+#define	COBEX_BFB_LOG_DOMAIN	"cobex-bfb"
+
 /* session handling */
 
-obex_ctrans_t *cobex_ctrans (const gchar *tty);
-void cobex_free (obex_ctrans_t * ctrans);
+obex_ctrans_t *
+	cobex_ctrans (const char *tty);
+void	cobex_free (obex_ctrans_t * ctrans);
 
 /* callbacks */
 
-gint cobex_connect (obex_t *self, gpointer userdata);
-gint cobex_disconnect (obex_t *self, gpointer userdata);
-gint cobex_write (obex_t *self, gpointer userdata, guint8 *buffer, gint length);
-gint cobex_handleinput (obex_t *self, gpointer userdata, gint timeout);
+int	cobex_connect (obex_t *self, void *data);
+int	cobex_disconnect (obex_t *self, void *data);
+int	cobex_write (obex_t *self, void *data, uint8_t *buffer, int length);
+int	cobex_handleinput (obex_t *self, void *data, int timeout);
 
-/* private */
+#ifdef __cplusplus
+}
+#endif
 
-int cobex_init (obex_t *self, const gchar *ttyname);
-void cobex_cleanup (obex_t *self, int force);
-int cobex_start_io (void);
+#endif /* COBEXBFB_H */
